#!/bin/sh

source /etc/profile

function set_common_error_code() {
	ERROR_NO_ERROR=0

	ERROR_INVALID_ARGS=1
	ERROR_NO_AUTH=2
	ERROR_NO_ENTRY=3

	ERROR_NO_SSID=11
	ERROR_FAIL_TO_GET_IP=12
	ERROR_INVALID_AP_PWD=13
	ERROR_RUNNING_NOW=14
	ERROR_RECORDING_NOW=15
	ERROR_NO_SD_CARD=16
	ERROR_TOO_MUCH_CLIENTS=17
	ERROR_DISK_IO_ERROR=18

	ERROR_UNKNOWN=255
}

function set_common_command_env() {
	AWK=/usr/bin/awk
	BASENAME=/usr/bin/basename
	CAT=/bin/cat
	CHMOD=/bin/chmod
	CP=/bin/cp
	CUT=/usr/bin/cut
	DATE=/bin/date
	ECHO=/bin/echo
	EGREP=/bin/egrep
	GREP=/bin/grep
	HEAD=/usr/bin/head
	JOURNALCTL=/usr/bin/journalctl
	KILL=/bin/kill
	LS=/bin/ls
	MKDIR=/bin/mkdir
	MKFIFO=/usr/bin/mkfifo
	PGREP=/usr/bin/pgrep
	PIDOF=/bin/pidof
	PKILL=/usr/bin/pkill
	PS=/bin/ps
	RM=/bin/rm 
	SED=/bin/sed
	SPCP=/usr/sbin/spcp
	SLEEP=/bin/sleep
	STAT=/bin/stat
	SYNC=/bin/sync
	SYFTST=/usr/sbin/syft.st
	SYSTEMCTL=/usr/bin/systemctl
	TAIL=/usr/bin/tail
	TAR=/bin/tar
	TR=/usr/bin/tr
	TOUCH=/bin/touch
	WC=/usr/bin/wc
}

function set_common_env() {
	TMP_FW_ENV=/tmp/.fwenv
	if [ ! -d $TMP_FW_ENV ]; then
		$MKDIR -p $TMP_FW_ENV
	fi
	FW_SECURE_LOG_DIR=/var/fwseclog.d
}

function set_cfg_env() {
# USAGE: <file> <environment> <value>
	CFG_FILE=$1
	$TOUCH $CFG_FILE
	$CHMOD +w $CFG_FILE
	ENV=$2
	ENV_VALUE=$3
	OLD_ENV=`$GREP "^${ENV}\=" $CFG_FILE`

	if [ "$OLD_ENV" != "" ]; then
		# edit env value to new one
		OLD_ENV=`$ECHO $OLD_ENV | $SED s,/,\\\\\\\\\\/,g`
		ENV_VALUE=`$ECHO $ENV_VALUE | $SED s,/,\\\\\\\\\\/,g`
		NEW_ENV="$ENV=$ENV_VALUE"
		$SED -i -- "s/\b${ENV}=.*/$ENV=\"$ENV_VALUE\"/g" $CFG_FILE
	else
		# create new environment
		NEW_ENV="$ENV=\"$ENV_VALUE\""
		$ECHO "$NEW_ENV" >> $CFG_FILE
	fi
}

function set_cfg_env_no_quot() {
# USAGE: <file> <environment> <value>
	CFG_FILE=$1
	$TOUCH $CFG_FILE
	$CHMOD +w $CFG_FILE
	ENV=$2
	ENV_VALUE=$3
	OLD_ENV=`$GREP "^${ENV}\=" $CFG_FILE`

	if [ "$OLD_ENV" != "" ]; then
		# edit env value to new one
		OLD_ENV=`echo $OLD_ENV | $SED s,/,\\\\\\\\\\/,g`
		ENV_VALUE=`echo $ENV_VALUE | $SED s,/,\\\\\\\\\\/,g`
		NEW_ENV="$ENV=$ENV_VALUE"
		$SED -i -- "s/\b${ENV}=.*/$ENV=$ENV_VALUE/g" $CFG_FILE
	else
		# create new environment
		NEW_ENV="$ENV=$ENV_VALUE"
		echo "$NEW_ENV" >> $CFG_FILE
	fi
}

function kill_proc(){
	proc_name=$1
	wait_seconds=$2
	if [ "$wait_seconds" == "" ]; then
		wait_seconds=3
	fi

	proc_id=`/bin/pidof $proc_name`
	[ "$proc_id" != "" ] && $KILL $proc_id

	try_count=0
	((max_count = wait_seconds * 10))
	while [ $try_count -lt $max_count ]
	do
	    /bin/usleep 100000
		proc_id=`/bin/pidof $proc_name`
		if [ "$proc_id" == "" ]; then
			return
		fi

	    ((try_count += 1))
		# $ECHO "$try_count"
	done

	[ "$proc_id" != "" ] && $KILL -9 $proc_id
}

function trim() {
	# removes leading and trailing whitespaces of args.
	# Ex: trim "  abc   def  " => "abc   def"
	local var="$*"
	# remove leading whitespace characters
	var="${var#"${var%%[![:space:]]*}"}"
	# remove trailing whitespace characters
	var="${var%"${var##*[![:space:]]}"}"   
	echo -n "$var"
}

function get_property_value_from_file() {
	# Returns value of property from file which contains property name-value pairs
	# Usage: get_property_value_from_file file_path property_name default_value [separator]
	#   if no file_path file, then returns default_value
	#   if separator is missing, then default separator (=) is used
	#   if separator is space, then use " " as separator
	# Exam.
	#   get_property_value_from_file $file_path HTTPS_PORT 443
	#   get_property_value_from_file $file_path HTTPS_PORT 443 =
	#   get_property_value_from_file $file_path Port 80 " "
	local file_path=$1
	local property_name=$2
	local default_value=$3
	local separator="$4"

	if [ ! -f $file_path ]; then
			$ECHO $default_value
			return
	fi

	local awk_field_separator="-F="
	if [ ! -z "$separator" ]; then
			if [ "$separator" != " " ]; then
					awk_field_separator="-F$separator"
			else
					awk_field_separator=""
			fi
	fi

	$ECHO `$CAT $file_path | $GREP "\b$property_name\b" | $AWK $awk_field_separator '{print $2}'`
}

function get_string_index() {
	# Returns the index of $2 in $1. If not found, then returns -1
	# Exam. get_string_index "123456789" "6789" -> returns 5
	#       get_string_index "123456789" "356" -> return -1
	local x="${1%%$2*}"
	[[ "$x" = "$1" ]] && echo -1 || echo "${#x}"
}

function function_exists() {
	declare -f -F $1 > /dev/null
	if [ "$?" -eq 0 ]; then
		$ECHO "1"
	else
		$ECHO "0"
	fi
}

set_common_error_code
set_common_command_env
set_common_env
